<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>Aumentar el volumen del sonido</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>Reducir el volumen del sonido</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>Silenciar/No silenciar el volumen del sonido</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>Control de volumen: los siguientes atajos no han podido registrarse: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="290"/>
        <source>Volume: %1%%2</source>
        <translation>Volumen: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="290"/>
        <source>(muted)</source>
        <translation>(silenciado)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>Configuración de Control de volumen</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>Dispositivo a controlar</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>Silenciar haciendo clic con el botón central</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>Permitir que el volumen sobrepase el 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Always notify about volume changes</source>
        <translation>Notificar siempre los cambios de volumen</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Notify about volume changes with keyboard</source>
        <translation>Notificar los cambios de volumen con el teclado</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>Paso del ajuste de volumen</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>Mezclador externo</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="59"/>
        <source>Launch mixer</source>
        <translation>Ejecuta el mezclador</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="60"/>
        <source>Mi&amp;xer</source>
        <translation>&amp;Mezclador</translation>
    </message>
</context>
</TS>
